@@ -60,6 +60,9 @@ void chat_commands_deinit(void);
 void log_away_init(void);
 void log_away_deinit(void);
 
+void wcwidth_wrapper_init(void);
+void wcwidth_wrapper_deinit(void);
+
 int irssi_gui;
 int irssi_init_finished;
 int reload_config;
@@ -258,6 +261,7 @@ void core_init(void)
 	nicklist_init();
 
 	chat_commands_init();
+	wcwidth_wrapper_init();
 
 	settings_add_str("misc", "ignore_signals", "");
 	settings_add_bool("misc", "override_coredump_limit", FALSE);
@@ -281,6 +285,7 @@ void core_deinit(void)
 	signal_remove("setup changed", (SIGNAL_FUNC) read_settings);
 	signal_remove("irssi init finished", (SIGNAL_FUNC) sig_irssi_init_finished);
 
+	wcwidth_wrapper_deinit();
 	chat_commands_deinit();
 
 	nicklist_deinit();
