@@ -206,7 +206,7 @@ static void server_real_connect(SERVER_REC *server, IPADDR *ip,
 	const char *errmsg;
 	char *errmsg2;
 	char ipaddr[MAX_IP_LEN];
-        int port;
+	int port = 0;
 
 	g_return_if_fail(ip != NULL || unix_socket != NULL);
 
@@ -219,12 +219,22 @@ static void server_real_connect(SERVER_REC *server, IPADDR *ip,
 		own_ip = IPADDR_IS_V6(ip) ? server->connrec->own_ip6 : server->connrec->own_ip4;
 		port = server->connrec->proxy != NULL ?
 			server->connrec->proxy_port : server->connrec->port;
-		handle = server->connrec->use_tls ?
-			net_connect_ip_ssl(ip, port, own_ip, server) : net_connect_ip(ip, port, own_ip);
+		handle = net_connect_ip(ip, port, own_ip);
 	} else {
 		handle = net_connect_unix(unix_socket);
 	}
 
+	if (server->connrec->use_tls && handle != NULL) {
+		server->handle = net_sendbuffer_create(handle, 0);
+		handle = net_start_ssl(server);
+		if (handle == NULL) {
+			net_sendbuffer_destroy(server->handle, TRUE);
+			server->handle = NULL;
+		} else {
+			server->handle->handle = handle;
+		}
+	}
+
 	if (handle == NULL) {
 		/* failed */
 		errmsg = g_strerror(errno);
@@ -244,7 +254,8 @@ static void server_real_connect(SERVER_REC *server, IPADDR *ip,
 		server_connect_failed(server, errmsg2 ? errmsg2 : errmsg);
 		g_free(errmsg2);
 	} else {
-		server->handle = net_sendbuffer_create(handle, 0);
+		if (!server->connrec->use_tls)
+			server->handle = net_sendbuffer_create(handle, 0);
 		if (server->connrec->use_tls)
 			server_connect_callback_init_ssl(server, handle);
 		else
