@@ -33,6 +33,8 @@
 #define isarg(c) \
 	(i_isdigit(c) || (c) == '*' || (c) == '~' || (c) == '-')
 
+#define ALIGN_MAX 222488
+
 static SPECIAL_HISTORY_FUNC history_func = NULL;
 
 static char *get_argument(char **cmd, char **arglist)
@@ -300,6 +302,10 @@ static int get_alignment_args(char **data, int *align, int *flags, char *pad)
 	if (!parse_uint(str, &endptr, 10, &align_)) {
 		return FALSE;
 	}
+	/* alignment larger than supported */
+	if (align_ > ALIGN_MAX) {
+		return FALSE;
+	}
 	str = endptr;
 	*align = align_;
 
@@ -337,11 +343,14 @@ char *get_alignment(const char *text, int align, int flags, char pad)
 
 	/* add pad characters */
 	if (flags & ALIGN_PAD) {
-		while (string_width(str->str, policy) < align) {
+		int pad_len = align - string_width(str->str, policy);
+		if (pad_len > 0) {
+			char *pad_full = g_strnfill(pad_len, pad);
 			if (flags & ALIGN_RIGHT)
-				g_string_prepend_c(str, pad);
+				g_string_prepend(str, pad_full);
 			else
-				g_string_append_c(str, pad);
+				g_string_append(str, pad_full);
+			g_free(pad_full);
 		}
 	}
 
