@@ -201,8 +201,7 @@ static void sig_message_public(SERVER_REC *server, const char *msg,
 	if (for_me)
 		level |= MSGLEVEL_HILIGHT;
 
-	if (ignore_check(server, nick, address, target, msg, level | MSGLEVEL_NO_ACT))
-		level |= MSGLEVEL_NO_ACT;
+	ignore_check_plus(server, nick, address, target, msg, &level, FALSE);
 
 	if (settings_get_bool("emphasis"))
 		msg = freemsg = expand_emphasis((WI_ITEM_REC *) chanrec, msg);
@@ -260,8 +259,7 @@ static void sig_message_private(SERVER_REC *server, const char *msg,
 	if (settings_get_bool("emphasis"))
 		msg = freemsg = expand_emphasis((WI_ITEM_REC *) query, msg);
 
-	if (ignore_check(server, nick, address, NULL, msg, level | MSGLEVEL_NO_ACT))
-		level |= MSGLEVEL_NO_ACT;
+	ignore_check_plus(server, nick, address, NULL, msg, &level, FALSE);
 
 	if (own) {
 		printformat(server, target, level,
@@ -355,8 +353,7 @@ static void sig_message_join(SERVER_REC *server, const char *channel,
 {
 	int level = MSGLEVEL_JOINS;
 
-	if (ignore_check(server, nick, address, channel, NULL, level | MSGLEVEL_NO_ACT))
-		level |= MSGLEVEL_NO_ACT;
+	ignore_check_plus(server, nick, address, channel, NULL, &level, FALSE);
 
 	printformat(server, channel, level,
 		    TXT_JOIN, nick, address, channel);
@@ -368,8 +365,7 @@ static void sig_message_part(SERVER_REC *server, const char *channel,
 {
 	int level = MSGLEVEL_PARTS;
 
-	if (ignore_check(server, nick, address, channel, NULL, level | MSGLEVEL_NO_ACT))
-		level |= MSGLEVEL_NO_ACT;
+	ignore_check_plus(server, nick, address, channel, NULL, &level, FALSE);
 
 	printformat(server, channel, level,
 		    TXT_PART, nick, address, channel, reason);
@@ -384,12 +380,9 @@ static void sig_message_quit(SERVER_REC *server, const char *nick,
 	char *print_channel;
 	int once, count, level = MSGLEVEL_QUITS;
 
-	if (ignore_check(server, nick, address, NULL, reason, MSGLEVEL_QUITS))
+	if (ignore_check_plus(server, nick, address, NULL, reason, &level, TRUE))
 		return;
 
-	if (ignore_check(server, nick, address, NULL, reason, level | MSGLEVEL_NO_ACT))
-		level |= MSGLEVEL_NO_ACT;
-
 	print_channel = NULL;
 	once = settings_get_bool("show_quit_once");
 
@@ -403,15 +396,12 @@ static void sig_message_quit(SERVER_REC *server, const char *nick,
 		if (!nicklist_find(rec, nick))
 			continue;
 
-		if (ignore_check(server, nick, address, rec->visible_name,
-				 reason, MSGLEVEL_QUITS)) {
+		if (ignore_check_plus(server, nick, address, rec->visible_name,
+				      reason, &level, TRUE)) {
 			count++;
 			continue;
 		}
 
-		if (ignore_check(server, nick, address, rec->visible_name, reason, MSGLEVEL_NO_ACT))
-			level |= MSGLEVEL_NO_ACT;
-
 		if (print_channel == NULL ||
 		    active_win->active == (WI_ITEM_REC *) rec)
 			print_channel = rec->visible_name;
@@ -458,8 +448,7 @@ static void sig_message_kick(SERVER_REC *server, const char *channel,
 {
 	int level = MSGLEVEL_KICKS;
 
-	if (ignore_check(server, kicker, address, channel, reason, level | MSGLEVEL_NO_ACT))
-		level |= MSGLEVEL_NO_ACT;
+	ignore_check_plus(server, kicker, address, channel, reason, &level, FALSE);
 
 	printformat(server, channel, level,
 		    TXT_KICK, nick, channel, kicker, reason, address);
@@ -472,15 +461,11 @@ static void print_nick_change_channel(SERVER_REC *server, const char *channel,
 {
 	int level;
 
-	if (ignore_check(server, oldnick, address,
-			 channel, newnick, MSGLEVEL_NICKS))
-		return;
-
 	level = MSGLEVEL_NICKS;
         if (ownnick) level |= MSGLEVEL_NO_ACT;
-
-	if (!(level & MSGLEVEL_NO_ACT) && ignore_check(server, oldnick, address, channel, newnick, level | MSGLEVEL_NO_ACT))
-		level |= MSGLEVEL_NO_ACT;
+	if (ignore_check_plus(server, oldnick, address,
+			      channel, newnick, &level, TRUE))
+		return;
 
 	printformat(server, channel, level,
 		    ownnick ? TXT_YOUR_NICK_CHANGED : TXT_NICK_CHANGED,
@@ -558,8 +543,7 @@ static void sig_message_topic(SERVER_REC *server, const char *channel,
 {
 	int level = MSGLEVEL_TOPICS;
 
-	if (ignore_check(server, nick, address, channel, topic, level | MSGLEVEL_NO_ACT))
-		level |= MSGLEVEL_NO_ACT;
+	ignore_check_plus(server, nick, address, channel, topic, &level, FALSE);
 
 	printformat(server, channel, level,
 		    *topic != '\0' ? TXT_NEW_TOPIC : TXT_TOPIC_UNSET,
