@@ -480,27 +480,30 @@ int format_real_length(const char *str, int len)
 
 	start = str;
 	tmp = g_string_new(NULL);
-	while (*str != '\0' && len > 0) {
+	while (*str != '\0') {
+		oldstr = str;
 		if (*str == '%' && str[1] != '\0') {
 			str++;
 			if (*str != '%') {
 			     adv = format_expand_styles(tmp, &str, NULL);
-			     str += adv;
-			     if (adv)
-				continue;
-			}
-
-			/* %% or unknown %code, written as-is */
-			if (*str != '%') {
-				if (--len == 0)
-					break;
+			     if (adv) {
+				     str += adv;
+				     continue;
+			     }
+			     /* discount for unknown % */
+			     if (--len < 0) {
+				     str = oldstr;
+				     break;
+			     }
+			     oldstr = str;
 			}
 		}
 
-		oldstr = str;
 		len -= string_advance(&str, utf8);
-		if (len < 0)
+		if (len < 0) {
 			str = oldstr;
+			break;
+		}
 	}
 
 	g_string_free(tmp, TRUE);
@@ -1118,7 +1121,7 @@ int strip_real_length(const char *str, int len,
 		*last_color_len = -1;
 
 	while (*str != '\0') {
-		if (*str == 3) {
+		if (*str == 3) { /* mIRC color */
 			const char *mircstart = str;
 
 			if (last_color_pos != NULL)
@@ -1129,6 +1132,9 @@ int strip_real_length(const char *str, int len,
 				*last_color_len = (int) (str-mircstart);
 
 		} else if (*str == 4 && str[1] != '\0') {
+			/* We expect 4 to indicate an internal Irssi color code. However 4
+			 * also means hex color, an alternative to mIRC color codes. We
+			 * don't support those. */
 #ifdef TERM_TRUECOLOR
 			if (str[1] == FORMAT_COLOR_24 && str[2] != '\0') {
 				if (str[3] == '\0') str++;
