@@ -12,21 +12,21 @@ enum {
 	TXT_DAYCHANGE,
 	TXT_TALKING_WITH,
 	TXT_REFNUM_TOO_LOW,
-        TXT_ERROR_SERVER_STICKY,
-        TXT_SET_SERVER_STICKY,
+	TXT_ERROR_SERVER_STICKY,
+	TXT_SET_SERVER_STICKY,
 	TXT_UNSET_SERVER_STICKY,
-        TXT_WINDOW_NAME_NOT_UNIQUE,
-        TXT_WINDOW_LEVEL,
-        TXT_WINDOW_SET_IMMORTAL,
-        TXT_WINDOW_UNSET_IMMORTAL,
-        TXT_WINDOW_IMMORTAL_ERROR,
+	TXT_WINDOW_NAME_NOT_UNIQUE,
+	TXT_WINDOW_LEVEL,
+	TXT_WINDOW_SET_IMMORTAL,
+	TXT_WINDOW_UNSET_IMMORTAL,
+	TXT_WINDOW_IMMORTAL_ERROR,
 	TXT_WINDOWLIST_HEADER,
 	TXT_WINDOWLIST_LINE,
 	TXT_WINDOWLIST_FOOTER,
 	TXT_WINDOWS_LAYOUT_SAVED,
 	TXT_WINDOWS_LAYOUT_RESET,
-        TXT_WINDOW_INFO_HEADER,
-        TXT_WINDOW_INFO_FOOTER,
+	TXT_WINDOW_INFO_HEADER,
+	TXT_WINDOW_INFO_FOOTER,
 	TXT_WINDOW_INFO_REFNUM,
 	TXT_WINDOW_INFO_REFNUM_STICKY,
 	TXT_WINDOW_INFO_NAME,
@@ -34,22 +34,22 @@ enum {
 	TXT_WINDOW_INFO_IMMORTAL,
 	TXT_WINDOW_INFO_SIZE,
 	TXT_WINDOW_INFO_LEVEL,
-        TXT_WINDOW_INFO_SERVER,
+	TXT_WINDOW_INFO_SERVER,
 	TXT_WINDOW_INFO_SERVER_STICKY,
-        TXT_WINDOW_INFO_THEME,
+	TXT_WINDOW_INFO_THEME,
 	TXT_WINDOW_INFO_BOUND_ITEMS_HEADER,
 	TXT_WINDOW_INFO_BOUND_ITEM,
 	TXT_WINDOW_INFO_BOUND_ITEMS_FOOTER,
 	TXT_WINDOW_INFO_ITEMS_HEADER,
 	TXT_WINDOW_INFO_ITEM,
-        TXT_WINDOW_INFO_ITEMS_FOOTER,
+	TXT_WINDOW_INFO_ITEMS_FOOTER,
 
 	TXT_FILL_2,
 
 	TXT_LOOKING_UP,
 	TXT_CONNECTING,
- 	TXT_RECONNECTING,
-        TXT_CONNECTION_ESTABLISHED,
+	TXT_RECONNECTING,
+	TXT_CONNECTION_ESTABLISHED,
 	TXT_CANT_CONNECT,
 	TXT_CONNECTION_LOST,
 	TXT_LAG_DISCONNECTED,
@@ -100,7 +100,7 @@ enum {
 	TXT_CHANSETUP_LINE,
 	TXT_CHANSETUP_FOOTER,
 
-        TXT_FILL_4,
+	TXT_FILL_4,
 
 	TXT_OWN_MSG,
 	TXT_OWN_MSG_CHANNEL,
@@ -162,7 +162,7 @@ enum {
 
 	TXT_MODULE_HEADER,
 	TXT_MODULE_LINE,
-        TXT_MODULE_FOOTER,
+	TXT_MODULE_FOOTER,
 	TXT_MODULE_ALREADY_LOADED,
 	TXT_MODULE_NOT_LOADED,
 	TXT_MODULE_LOAD_ERROR,
@@ -183,7 +183,7 @@ enum {
 	TXT_NOT_JOINED,
 	TXT_CHAN_NOT_FOUND,
 	TXT_CHAN_NOT_SYNCED,
-        TXT_ILLEGAL_PROTO,
+	TXT_ILLEGAL_PROTO,
 	TXT_NOT_GOOD_IDEA,
 	TXT_INVALID_NUMBER,
 	TXT_INVALID_TIME,
@@ -232,8 +232,8 @@ enum {
 
 	TXT_FILL_14,
 
-        TXT_UNKNOWN_CHAT_PROTOCOL,
-        TXT_UNKNOWN_CHATNET,
+	TXT_UNKNOWN_CHAT_PROTOCOL,
+	TXT_UNKNOWN_CHATNET,
 	TXT_NOT_TOGGLE,
 	TXT_PERL_ERROR,
 	TXT_BIND_HEADER,
@@ -245,16 +245,19 @@ enum {
 	TXT_CONFIG_RELOADED,
 	TXT_CONFIG_MODIFIED,
 	TXT_GLIB_ERROR,
-        TXT_OVERWRITE_CONFIG,
-        TXT_SET_TITLE,
-        TXT_SET_ITEM,
-        TXT_SET_UNKNOWN,
+	TXT_OVERWRITE_CONFIG,
+	TXT_SET_TITLE,
+	TXT_SET_ITEM,
+	TXT_SET_UNKNOWN,
 	TXT_SET_NOT_BOOLEAN,
 	TXT_NO_COMPLETIONS,
-        TXT_COMPLETION_REMOVED,
+	TXT_COMPLETION_REMOVED,
 	TXT_COMPLETION_HEADER,
-        TXT_COMPLETION_LINE,
+	TXT_COMPLETION_LINE,
 	TXT_COMPLETION_FOOTER,
+	TXT_CAPSICUM_ENABLED,
+	TXT_CAPSICUM_DISABLED,
+	TXT_CAPSICUM_FAILED,
 
 	TLS_FILL_15,
 
