@@ -654,7 +654,7 @@ void gui_entry_insert_char(GUI_ENTRY_REC *entry, unichar chr)
 	if (chr == 0 || chr == 13 || chr == 10)
 		return; /* never insert NUL, CR or LF characters */
 
-	if (entry->utf8 && entry->pos == 0 && i_wcwidth(chr) == 0)
+	if (entry->utf8 && entry->pos == 0 && unichar_isprint(chr) && i_wcwidth(chr) == 0)
 		return;
 
 	gui_entry_redraw_from(entry, entry->pos);
@@ -835,8 +835,8 @@ void gui_entry_erase(GUI_ENTRY_REC *entry, int size, CUTBUFFER_UPDATE_OP update_
 	}
 
 	if (entry->utf8)
-		while (entry->pos-size-w > 0 &&
-		       i_wcwidth(entry->text[entry->pos-size-w]) == 0) w++;
+		while (entry->pos > size + w && i_wcwidth(entry->text[entry->pos - size - w]) == 0)
+			w++;
 
 	g_memmove(entry->text + entry->pos - size, entry->text + entry->pos,
 		  (entry->text_len-entry->pos+1) * sizeof(unichar));
