@@ -54,6 +54,11 @@ void fe_perl_init(void);
 void fe_perl_deinit(void);
 #endif
 
+#ifdef HAVE_STATIC_OTR
+void otr_core_init(void);
+void otr_core_deinit(void);
+#endif
+
 void irc_init(void);
 void irc_deinit(void);
 
@@ -156,6 +161,7 @@ static void textui_init(void)
 
 static void textui_finish_init(void)
 {
+	int loglev;
 	quitting = FALSE;
 
 	term_refresh_freeze();
@@ -165,12 +171,16 @@ static void textui_finish_init(void)
 	gui_expandos_init();
 	gui_printtext_init();
 	gui_readline_init();
+	gui_entry_init();
 	lastlog_init();
 	mainwindows_init();
 	mainwindow_activity_init();
 	mainwindows_layout_init();
 	gui_windows_init();
+	/* Temporarily raise the fatal level to abort on config errors. */
+	loglev = g_log_set_always_fatal(G_LOG_FATAL_MASK | G_LOG_LEVEL_CRITICAL);
 	statusbar_init();
+	g_log_set_always_fatal(loglev);
 	term_refresh_thaw();
 
 	settings_check();
@@ -182,6 +192,10 @@ static void textui_finish_init(void)
 	fe_perl_init();
 #endif
 
+#ifdef HAVE_STATIC_OTR
+	otr_core_init();
+#endif
+
 	dirty_check();
 
 	fe_common_core_finish_init();
@@ -220,8 +234,12 @@ static void textui_deinit(void)
 		module_unload(modules->data);
 
 #ifdef HAVE_STATIC_PERL
-        perl_core_deinit();
-        fe_perl_deinit();
+	perl_core_deinit();
+	fe_perl_deinit();
+#endif
+
+#ifdef HAVE_STATIC_OTR
+	otr_core_deinit();
 #endif
 
 	dirty_check(); /* one last time to print any quit messages */
@@ -230,6 +248,7 @@ static void textui_deinit(void)
 
 	lastlog_deinit();
 	statusbar_deinit();
+	gui_entry_deinit();
 	gui_printtext_deinit();
 	gui_readline_deinit();
 	gui_windows_deinit();
@@ -304,6 +323,7 @@ int main(int argc, char **argv)
 	   you have to call setlocale(LC_ALL, "") */
 	setlocale(LC_ALL, "");
 
+	/* Temporarily raise the fatal level to abort on config errors. */
 	loglev = g_log_set_always_fatal(G_LOG_FATAL_MASK | G_LOG_LEVEL_CRITICAL);
 	textui_init();
 
