@@ -451,7 +451,11 @@ static void sig_destroyed(IRC_SERVER_REC *server)
 	gslist_free_full(server->cap_queue, (GDestroyNotify) g_free);
 	server->cap_queue = NULL;
 
-	g_free_and_null(server->sasl_buffer);
+	/* was g_free_and_null, but can't use on a GString */
+	if (server->sasl_buffer != NULL) {
+		g_string_free(server->sasl_buffer, TRUE);
+		server->sasl_buffer = NULL;
+	}
 
 	/* these are dynamically allocated only if isupport was sent */
 	g_hash_table_foreach(server->isupport,
