@@ -57,8 +57,9 @@ void dcc_unregister_type(const char *type)
 
 	pos = gslist_find_string(dcc_types, type);
 	if (pos != NULL) {
-		g_free(pos->data);
-                dcc_types = g_slist_remove(dcc_types, pos->data);
+		void *tmp = pos->data;
+		dcc_types = g_slist_remove(dcc_types, pos->data);
+		g_free(tmp);
 	}
 }
 
