@@ -9,17 +9,18 @@
 
 typedef struct {
 	int port;
+	char *port_or_path;
 	char *ircnet;
 
 	int tag;
 	GIOChannel *handle;
 
 	GSList *clients;
+
 } LISTEN_REC;
 
 typedef struct {
-	char *nick, *host;
-	int port;
+	char *nick, *addr;
 	NET_SENDBUF_REC *handle;
 	int recv_tag;
 	char *proxy_address;
@@ -29,6 +30,7 @@ typedef struct {
 	unsigned int user_sent:1;
 	unsigned int connected:1;
 	unsigned int want_ctcp:1;
+	unsigned int multiplex:1;
 } CLIENT_REC;
 
 #endif
